@@ -1,15 +1,19 @@
 from .abi import ABI
+from .base import BaseModel
 from .contract_type import Bytecode, ContractInstance, ContractType
 from .manifest import PackageManifest, PackageMeta
 from .source import Checksum, Compiler, Source
+from .utils import HexBytes
 
 __all__ = [
     "ABI",
+    "BaseModel",
     "Bytecode",
     "Checksum",
     "Compiler",
     "ContractInstance",
     "ContractType",
+    "HexBytes",
     "PackageMeta",
     "PackageManifest",
     "Source",
