@@ -1,5 +1,9 @@
+from typing import Any, no_type_check
+
 from pydantic import BaseModel as _BaseModel
 
+from .utils import HexBytes
+
 
 class BaseModel(_BaseModel):
     def dict(self, *args, **kwargs) -> dict:
@@ -33,3 +37,21 @@ class BaseModel(_BaseModel):
             kwargs["exclude_none"] = True
 
         return super().json(*args, **kwargs)
+
+    @classmethod
+    @no_type_check
+    def _get_value(
+        cls,
+        v: Any,
+        *args,
+        **kwargs,
+    ) -> Any:
+
+        if isinstance(v, HexBytes):
+            return v.hex()
+
+        return super()._get_value(
+            v,
+            *args,
+            **kwargs,
+        )
